Hamiltonian Functions
=====================

Some useful functions for creating various 'generic' Hamiltonians (i.e. useful
for alkali atoms), including their field dependent & independent parts, and
connections between various manifolds.

Note: The Hamiltonians have the value of the Bohr magneton specified in Hz/G
by default. To use `pylcp` default units, the Bohr magneton values must be
overridden.

Other Hamiltonians
------------------

In addition to the Hamiltonians specified here, there are other, more
specialized Hamiltonians for other quantum systems like molecules.

.. toctree::
  :maxdepth: 1

  hamiltonians_molecular

Overview
--------

.. currentmodule:: pylcp.hamiltonians

.. autosummary::

    singleF
    hyperfine_uncoupled
    hyperfine_coupled
    fine_structure_uncoupled
    dqij_two_bare_hyperfine
    dqij_two_hyperfine_manifolds
    dqij_two_fine_stucture_manifolds_uncoupled


Detailed functions
------------------

.. automodule:: pylcp.hamiltonians
  :members:
